#
# spec file for package geda-gaf
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define libgeda_major 46
%define libgedacairo_major 1
%define libxorn_major 0
Name:           geda-gaf
Version:        1.10.0
Release:        bp153.1.21
Summary:        Electronic Design Automation Toolsuite
License:        GPL-2.0-or-later
Group:          Productivity/Scientific/Electronics
URL:            http://geda-project.org/
Source0:        http://ftp.geda-project.org/geda-gaf/stable/v1.10/%{version}/%{name}-%{version}.tar.gz
Source1:        geda-gaf-rpmlintrc
# PATCH-FIX-OPENSUSE gschem-doc-path.patch -- set correct path to documentation
Patch0:         gschem-doc-path.patch
# PATCH-FIX-OPENSUSE grenum-no-build-time.patch -- fix "W: file-contains-date-and-time"
Patch1:         grenum-no-build-time.patch
# PATCH-FIX-OPENSUSE geda-gaf-disable-failing-tests.patch -- disable failing tests
Patch3:         geda-gaf-disable-failing-tests.patch
# PATCH-FIX-OPENSUSE geda-gaf-enable-guile-2.2.patch -- enable guile-2.2 (for Factory/TW)
Patch5:         xorn-enable-guile-2.2.patch
# PATCH-FIX-OPENSUSE geda-gaf-enable-guile-2.0.patch -- enable guile-2.0 (for older distros)
Patch6:         geda-gaf-enable-guile-2.0.patch
# PATCH-FIX-OPENSUSE geda-gaf-fix-uninitialized-variable.patch -- avoid build crash on potentially
# uninitialized variables (for Factory/TW)
Patch7:         geda-gaf-fix-uninitialized-variable.patch
BuildRequires:  bison
BuildRequires:  cairo-devel
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  flex
BuildRequires:  gamin-devel
BuildRequires:  gcc-c++
BuildRequires:  gdk-pixbuf-devel
BuildRequires:  gettext-tools
BuildRequires:  groff
BuildRequires:  gtk2-devel
BuildRequires:  guile-devel
BuildRequires:  intltool
# Required for Patch4
BuildRequires:  libtool
BuildRequires:  perl-XML-Parser
BuildRequires:  pkg-config
BuildRequires:  python2-devel
BuildRequires:  shared-mime-info
BuildRequires:  transfig
BuildRequires:  update-desktop-files
Requires:       geda-gattrib = %{version}
Requires:       geda-gnetlist = %{version}
Requires:       geda-gschem = %{version}
Requires:       geda-gsymcheck = %{version}
Requires:       geda-symbols = %{version}
Requires:       geda-utils = %{version}
Requires:       pcb
Recommends:     geda-doc
Recommends:     geda-examples

%description
This is a toolkit of Electronic Design Automation tools. They are
used for circuit design, schematic capture, simulation, prototyping,
and production.

%package     -n libgeda%{libgeda_major}
Summary:        Basic Library that is used by several gEDA programs
License:        GPL-2.0-or-later
Group:          System/Libraries
Requires:       libgeda-data >= %{version}

%description -n libgeda%{libgeda_major}
This package provides the basic library for several gEDA programs
related to electronic design automation.

%package     -n libgeda-data
Summary:        Data for basic Library that is used by several gEDA programs
License:        GPL-2.0-or-later
Group:          Productivity/Scientific/Electronics
Requires(post): shared-mime-info
Requires(postun): shared-mime-info
# Existed up to Leap 15.1:
#Obsoletes:      libgeda42-data <= %{version}
# In fact, translations are not provided, but previous versions vere
# incorrectly packaged, and there is no better way to proceed:
#Provides:       libgeda42-data <= %{version}
# This existed only in OBS project electronics:
Obsoletes:      libgeda%{libgeda_major}-data < %{version}
Provides:       libgeda%{libgeda_major}-data = %{version}
BuildArch:      noarch

%description -n libgeda-data
This package provides data files for libgeda such as icons required by several
gEDA programs.

%package     -n libgeda-devel
Summary:        Development files for gEDA
License:        GPL-2.0-or-later
Group:          Development/Libraries/C and C++
Requires:       glib2-devel
Requires:       gtk2-devel
Requires:       guile-devel
Requires:       libgeda%{libgeda_major} = %{version}
Requires:       libjpeg-devel
Requires:       libpng-devel

%description -n libgeda-devel
This package provides headers for libgeda.

%package     -n libgedacairo%{libgedacairo_major}
Summary:        Schematic renderer library
License:        GPL-2.0-or-later
Group:          System/Libraries

%description -n libgedacairo%{libgedacairo_major}
This package provides a schematic renderer library.

%package     -n libgedacairo-devel
Summary:        Development files for libgedacairo
License:        GPL-2.0-or-later
Group:          Development/Libraries/C and C++
Requires:       libgedacairo%{libgedacairo_major} = %{version}

%description -n libgedacairo-devel
This package provides headers for libgedacairo.

%package     -n libxornstorage%{libxorn_major}
Summary:        Schematic renderer library
License:        GPL-2.0-or-later
Group:          System/Libraries

%description -n libxornstorage%{libxorn_major}
This package provides a schematic renderer library.

%package     -n libxornstorage-devel
Summary:        Development files for libgedacairo
License:        GPL-2.0-or-later
Group:          Development/Libraries/C and C++
Requires:       libxornstorage%{libxorn_major} = %{version}

%description -n libxornstorage-devel
This package provides headers for libgedacairo.

%package     -n geda-base
Summary:        Common code for gEDA applications
License:        GPL-2.0-or-later
Group:          Productivity/Scientific/Electronics
Requires:       geda-xorn = %{version}

%description -n geda-base
This package provides code common to all gEDA applications.

%package     -n geda-doc
Summary:        Documentation Files for the gEDA Suite
License:        GFDL-1.2-only
Group:          Documentation/Other
BuildArch:      noarch

%description -n geda-doc
This package contains the documentation of the gEDA suite.
The documentation is a snapshot of the gEDA wiki located at
http://wiki.geda-project.org/.

%package     -n geda-examples
Summary:        Some Example Files for the gEDA suite
License:        GPL-2.0-or-later
Group:          Documentation/Other
Requires:       geda-symbols = %{version}
BuildArch:      noarch

%description -n geda-examples
Package with four example projects realized with gEDA.

%package     -n geda-gattrib
Summary:        Symbol and Schematic Attribute Editor of the gEDA Suite
License:        GPL-2.0-or-later
Group:          Productivity/Scientific/Electronics
Requires:       geda-base = %{version}
Requires:       geda-symbols = %{version}

%description -n geda-gattrib
With gattrib, attributes of schematic or symbol files can be edited. It has
a spreadsheet-like GUI. gattrib is part of the gEDA suite.

%package     -n geda-gnetlist
Summary:        Schematic Netlist Generator Program of the gEDA Suite
License:        GPL-2.0-or-later
Group:          Productivity/Scientific/Electronics
Requires:       geda-base = %{version}
Requires:       geda-symbols = %{version}

%description -n geda-gnetlist
gnetlist is the netlist generator program of the gEDA suite. It reads
schematic files and converts them into different connecitity netlists.
gnetlist has several backends to generate netlists for PCB, Spice,
VHDL, Verilog and many other programs.

%package     -n geda-gschem
Summary:        Schematic Capture Program of the gEDA Suite
License:        GPL-2.0-or-later
Group:          Productivity/Scientific/Electronics
Requires:       geda-base = %{version}
Requires:       geda-symbols = %{version}
Recommends:     geda-doc

%description -n geda-gschem
gschem is the schematic capture program of the gEDA suite.
Schematics for simulation, PCB production or documentation can be drawn.
Hierarchical schematics are supported.

%package     -n geda-gsymcheck
Summary:        Schematic Symbol Checker Program of the gEDA Suite
License:        GPL-2.0-or-later
Group:          Productivity/Scientific/Electronics
Requires:       geda-base = %{version}
Requires:       geda-symbols = %{version}

%description -n geda-gsymcheck
gsymcheck is a symbol checker of the gEDA suite. It checks symbols for
missing or duplicate pins, missing attributes and definitions.

%package     -n geda-xorn
Summary:        Schematic Symbol Checker Program of the gEDA Suite
License:        GPL-2.0-or-later
Group:          Productivity/Scientific/Electronics
Requires:       libxornstorage%{libxorn_major} = %{version}

%description -n geda-xorn
gsymcheck is a symbol checker of the gEDA suite. It checks symbols for
missing or duplicate pins, missing attributes and definitions.

%package     -n geda-symbols
Summary:        Schematic Symbols for the gEDA Suite
License:        GPL-2.0-or-later
Group:          Productivity/Scientific/Electronics
BuildArch:      noarch

%description -n geda-symbols
Package with schematic symbols for the gEDA suite.

%package     -n geda-utils
Summary:        Various Utilities and Scripts for the gEDA Suite
License:        GPL-2.0-or-later
Group:          Productivity/Scientific/Electronics
Requires:       geda-base = %{version}
Requires:       geda-symbols = %{version}

%description -n geda-utils
This utility package contains several helper utilities for the gEDA
suite, containing an advanced PCB netlister gsch2pcb, symbol converters and
creators, refdes renumbering tools and many others.

%prep
%setup -q
%patch0 -p1
%patch1 -p1
%patch3 -p1
%if 0%{?suse_version} > 1510
%patch5 -p1
%patch7 -p1
%else
%patch6 -p1
%endif

%build
# export LDFLAGS="-lm $LDFLAGS"
# Required for Patch4
./autogen.sh
%configure  \
            --docdir=%{_docdir}/%{name} \
            --disable-static \
            --disable-rpath \
            --disable-update-xdg-database
make %{?_smp_mflags}

%install
%make_install

find %{buildroot} -type f -name "*.la" -delete -print
find %{buildroot}%{_libdir}/python*/site-packages/ -name '*.pyo' -exec rm {} \;
find %{buildroot}%{_libdir}/xorn/ -name '*.pyo' -exec rm {} \;

%suse_update_desktop_file -r geda-gschem Education Engineering
%suse_update_desktop_file -r geda-gattrib Education Engineering

%fdupes -s %{buildroot}%{_docdir}/geda-gaf/examples
%fdupes -s %{buildroot}%{_docdir}/geda-gaf/wiki

%find_lang geda-gaf
%find_lang geda-gattrib
%find_lang geda-gnetlist-legacy
%find_lang geda-gschem
%find_lang geda-gsymcheck
%find_lang libgeda%{libgeda_major}

%check
#make %{?_smp_mflags} check

%post -n libgeda%{libgeda_major} -p /sbin/ldconfig
%postun -n libgeda%{libgeda_major} -p /sbin/ldconfig
%post -n libgedacairo%{libgedacairo_major} -p /sbin/ldconfig
%postun -n libgedacairo%{libgedacairo_major} -p /sbin/ldconfig
%post -n libxornstorage%{libxorn_major} -p /sbin/ldconfig
%postun -n libxornstorage%{libxorn_major} -p /sbin/ldconfig
%post -n libgeda-data
%install_info --info-dir=%{_infodir} %{_infodir}/geda-scheme.info.gz
%{_bindir}/update-mime-database %{_datadir}/mime > /dev/null 2>&1 || :

%postun -n libgeda-data
%install_info_delete --info-dir=%{_infodir} %{_infodir}/geda-scheme.info.gz
%{_bindir}/update-mime-database %{_datadir}/mime > /dev/null 2>&1 || :

%files
%doc AUTHORS ChangeLog NEWS README

%files -n libgeda%{libgeda_major} -f libgeda%{libgeda_major}.lang
%{_libdir}/libgeda.so.%{libgeda_major}*

%files -n libgeda-data
%dir %{_datadir}/gEDA
%dir %{_datadir}/gEDA/scheme
%dir %{_datadir}/gEDA/icons
%dir %{_datadir}/gEDA/icons/hicolor
%dir %{_datadir}/gEDA/icons/hicolor/16x16
%dir %{_datadir}/gEDA/icons/hicolor/22x22
%{_datadir}/gEDA/gafrc.d
%{_datadir}/gEDA/system-gafrc
%{_datadir}/gEDA/print-colormap-lightbg
%{_datadir}/gEDA/print-colormap-darkbg
%{_datadir}/gEDA/scheme/geda.scm
%{_datadir}/gEDA/scheme/color-map.scm
%{_datadir}/gEDA/icons/hicolor/*/actions*
%{_datadir}/icons/hicolor/*/mimetypes/*
%{_datadir}/mime/packages/libgeda.xml
%{_infodir}/geda-scheme.info%{?ext_info}

%files -n libgeda-devel
%{_includedir}/libgeda/
%{_libdir}/libgeda.so
%{_libdir}/pkgconfig/libgeda.pc

%files -n libgedacairo%{libgedacairo_major}
%{_libdir}/libgedacairo.so.%{libgedacairo_major}*

%files -n libgedacairo-devel
%{_includedir}/libgedacairo/
%{_libdir}/libgedacairo.so
%{_libdir}/pkgconfig/libgedacairo.pc

%files -n libxornstorage%{libxorn_major}
%{_libdir}/libxornstorage.so.%{libxorn_major}*

%files -n libxornstorage-devel
%{_includedir}/xornstorage.h
%{_libdir}/libxornstorage.so

%files -n geda-doc
%dir %{_docdir}/%{name}
%doc %{_docdir}/%{name}/gedadocs.html
%doc %{_docdir}/%{name}/nc.pdf
%doc %{_docdir}/%{name}/man/
%doc %{_docdir}/%{name}/readmes/
%doc %{_docdir}/%{name}/wiki/

%files -n geda-examples
%dir %{_docdir}/%{name}
%{_docdir}/%{name}/examples/

%files -n geda-gattrib -f geda-gattrib.lang
%{_bindir}/gattrib
%{_datadir}/gEDA/system-gattribrc
%{_datadir}/gEDA/gattrib-menus.xml
%{_datadir}/icons/hicolor/*/apps/geda-gattrib.*
%{_datadir}/applications/geda-gattrib.desktop
%{_mandir}/man1/gattrib.1%{?ext_man}

%files -n geda-gnetlist -f geda-gnetlist-legacy.lang
%{_bindir}/gnetlist
%{_bindir}/gnetlist-legacy
%{python_sitearch}/gaf/netlist
%{_datadir}/gEDA/scheme/gnetlist
%{_datadir}/gEDA/system-gnetlistrc
%{_datadir}/gEDA/scheme/gnet-*.scm
%{_datadir}/gEDA/scheme/gnetlist-post.scm
%{_datadir}/gEDA/scheme/gnetlist.scm
%{_datadir}/gEDA/scheme/partslist-common.scm
%{_mandir}/man1/gnetlist.1%{?ext_man}
%{_mandir}/man1/gnetlist-legacy.1%{?ext_man}

%files -n geda-gschem -f geda-gschem.lang
%dir %{_datadir}/gEDA/scheme/gschem
%dir %{_datadir}/gEDA/scheme/gschem/core
%{_bindir}/gschem
%{_datadir}/gEDA/system-gschemrc
%{_datadir}/gEDA/gschem-gtkrc
%{_datadir}/gEDA/gschem-colormap-darkbg
%{_datadir}/gEDA/gschem-colormap-lightbg
%{_datadir}/gEDA/gschem-colormap-whitebg
%{_datadir}/gEDA/gschem-colormap-whitebg-bw
%{_datadir}/gEDA/gschem-colormap-bw
%{_datadir}/gEDA/scheme/pcb.scm
%{_datadir}/gEDA/scheme/auto-uref.scm
%{_datadir}/gEDA/scheme/auto-refdes.scm
%{_datadir}/gEDA/scheme/gschem.scm
%{_datadir}/gEDA/scheme/auto-place-attribs.scm
%{_datadir}/gEDA/scheme/auto-place-netname.scm
%{_datadir}/gEDA/scheme/print.scm
%{_datadir}/gEDA/scheme/default-attrib-positions.scm
%{_datadir}/gEDA/scheme/generate_netlist.scm
%{_datadir}/gEDA/scheme/geda-deprecated-config.scm
%{_datadir}/gEDA/scheme/gschem-deprecated-config.scm
%{_datadir}/gEDA/scheme/image.scm
%{_datadir}/gEDA/scheme/list-keys.scm
%{_datadir}/gEDA/scheme/spice-common.scm
%{_datadir}/gEDA/scheme/print-NB-attribs.scm
%{_datadir}/gEDA/scheme/gschem/action.scm
%{_datadir}/gEDA/scheme/gschem/attrib.scm
%{_datadir}/gEDA/scheme/gschem/builtins.scm
%{_datadir}/gEDA/scheme/gschem/core/gettext.scm
%{_datadir}/gEDA/scheme/gschem/deprecated.scm
%{_datadir}/gEDA/scheme/gschem/gschemdoc.scm
%{_datadir}/gEDA/scheme/gschem/hook.scm
%{_datadir}/gEDA/scheme/gschem/keymap.scm
%{_datadir}/gEDA/scheme/gschem/repl.scm
%{_datadir}/gEDA/scheme/gschem/selection.scm
%{_datadir}/gEDA/scheme/gschem/util.scm
%{_datadir}/gEDA/scheme/gschem/window.scm
%{_datadir}/gEDA/bitmap
%{_datadir}/icons/hicolor/*/apps/geda-gschem.*
%{_datadir}/applications/geda-gschem.desktop
%{_mandir}/man1/gschem.1%{?ext_man}

%files -n geda-base
%license COPYING
%dir %{_datadir}/gEDA/scheme/geda
%dir %{_datadir}/gEDA/scheme/geda/core
%{_datadir}/gEDA/scheme/geda/attrib.scm
%{_datadir}/gEDA/scheme/geda/config.scm
%{_datadir}/gEDA/scheme/geda/deprecated.scm
%{_datadir}/gEDA/scheme/geda/log.scm
%{_datadir}/gEDA/scheme/geda/object.scm
%{_datadir}/gEDA/scheme/geda/os.scm
%{_datadir}/gEDA/scheme/geda/page.scm
%{_datadir}/gEDA/scheme/geda/core/gettext.scm
%{python_sitearch}/gaf
%exclude %{python_sitearch}/gaf/netlist

%files -n geda-gsymcheck -f geda-gsymcheck.lang
%{_bindir}/gsymcheck
%{_datadir}/gEDA/system-gsymcheckrc
%{_mandir}/man1/gsymcheck.1%{?ext_man}

%files -n geda-xorn
%{_bindir}/xorn
%{_libdir}/xorn
%{python_sitearch}/xorn

%files -n geda-symbols
%{_datadir}/gEDA/sym
%{_datadir}/gEDA/extra-sym

%files -n geda-utils -f geda-gaf.lang
%{_bindir}/gaf
%{_bindir}/garchive
%{_bindir}/grenum
%{_bindir}/gsch2pcb
%{_bindir}/gschlas
%{_bindir}/gsymfix
%{_bindir}/gxyrs
%{_bindir}/pcb_backannotate
%{_bindir}/refdes_renum
%{_bindir}/schdiff
%{_bindir}/tragesym
%{_mandir}/man1/gaf.1%{?ext_man}
%{_mandir}/man1/garchive.1%{?ext_man}
%{_mandir}/man1/grenum.1%{?ext_man}
%{_mandir}/man1/gsch2pcb.1%{?ext_man}
%{_mandir}/man1/gschlas.1%{?ext_man}
%{_mandir}/man1/gsymfix.1%{?ext_man}
%{_mandir}/man1/gxyrs.1%{?ext_man}
%{_mandir}/man1/pcb_backannotate.1%{?ext_man}
%{_mandir}/man1/refdes_renum.1%{?ext_man}
%{_mandir}/man1/schdiff.1%{?ext_man}
%{_mandir}/man1/tragesym.1%{?ext_man}
%{_datadir}/gEDA/perl/
%{_datadir}/gEDA/system-gschlasrc

%changelog
* Tue Mar 31 2020 Wojciech Kazubski <wk@ire.pw.edu.pl>
- fixed source URL
* Wed Feb 26 2020 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Updated to release 1.10.0
- General changes
  * Added the library "xornstorage" and the Python package "gaf" as a
    (currently quite minimal) way to access gEDA/gaf functionality from
    outside of gschem.  These are on the long term intended to replace
    libgeda, making the core gEDA/gaf functionality available as a
    library to both gschem and other applications.
  * Added command-line tool `xorn' for low-level schematic and symbol
    file manipulation.
  * The symbol directories "gnetman", "verilog", and "vhdl" are now
    installed to the new location PREFIX/share/gEDA/extra-sym/.  This
    allows adding the default library with "component-library-search".
  * The directory to which gEDA programs write log transcripts can be
    changed by setting the environment variable `GEDALOG' (the default
    being ~/.gEDA/logs/).
  * Numerous ixed bugs.
- gschem changes
  * Tool windows are now "dockable", i.e., they can be either used as
    modal/non-modal dialogs or docked to the edges of the main window.
  * The action mechanism used for menu items, tool buttons, and key
    bindings has been redesigned.
  * The menus, toolbar, and keymap have been revamped to more closely
    resemble the "standards" for a desktop application.  Some actions
    have been assigned more accessible or memorable keys.
  * Attaching and detaching attributes now work as expected:
  * Fixed "Lock Component" and "Unlock Component"
  * Added new  color schemes
  * Symbol editing has been improved:
  * Added support for back-annotation from pcb-rnd.
  * Double-clicking a subschematic component enters the subschematic.
  * Right-clicking in path mode works as expected.
  * Pins are allowed to have zero length.
  * "File / Revert" only asks for confirmation if the file has been
    modified.
  * The "repeat" function of the middle mouse button now evaluates
    actions at the current mouse position.
  * Mouse gestures work properly again.
  * Added new mouse gestures for page navigation:
  - swiping left goes to the previous, swiping right to the next page
  - swiping right and then down enters a subschmatic
  - swiping left and then down enters a symbol
  - swiping up and sideways (in any combination) goes back to the
    parent schematic
  * The coordinate dialog has been replaced with an option to display
    the coordinates in the status bar.
  * Added further menu items:
  - "Add / Last Component" (A C)
  - "Object / Toggle Text Overbar" (T O)
  - "View / Show Menubar" (V M)
  - "View / Show Toolbar" (V T)
  - "View / Show Scrollbars" (V S)
  - "Tools / Select Locked Objects" (T L)
  * Fixed various issues related to undo/redo:
- gnetlist changes
  * Refactored gnetlist:
  - Netlist backends can also be written in Python.
  - When reading broken schematics and/or symbols, gnetlist doesn't
    silently fail or produce bad output any more.
  - In case there should be any problems with the refactored codebase,
    the "old" gnetlist is still available as "gnetlist-legacy".
  * There are new semantics for power and I/O port symbols.
  * Hierarchical schematics can now use a simple form of parametrization
    where the instantiating component contains an attribute of the form
    `param=NAME=VALUE' and some attribute value in the subschematic
    contains the pattern `$(NAME)', which will be replaced with `VALUE'.
  * Duplicate I/O ports in subschematics and duplicate I/O pins in
    subschematic symbols are now treated correctly.
  * Added a netlist backend for pcb-rnd's tEDAx format.
  * Added backends which dump the netlist in various generic formats.
- For more detailed information see NEWS file.
- patch #2: fix-gxyrs-utility.patch removed (applied upstream)
- patch #4: geda-gaf-enable-guile-2.2.patch removed (applied upstream)
- patch #5: xorn-enable-guile-2.2.patch added to build xorn with guile
  2.2 on Factory / Tumbleweed
- patch #6: geda-gaf-enable-guile-2.0.patch added to revert changes
  introduced by upstreaming patch #4 (used for older releases)
- patch #7: geda-gaf-fix-uninitialized-variable.patch added on
  Tumbleweed to prevent build failing with latest gcc
- Removed requirement for geda-xgsch2pcb - now PCB can directly import
  schematic files.
* Wed Jul 31 2019 sbrabec@suse.com
- Prevent conflict of libgeda42-data and libgeda45-data:
  * Rename package with unversioned files to libgeda-data.
  * Move versioned lang files to libgeda45.
- Process with spec-cleaner.
* Fri Mar 22 2019 Jonathan Brielmaier <jbrielmaier@suse.de>
- Update to version 1.9.2:
  * Guile 2.0 or newer is now required
  * `gpstoimage' has been removed from the distribution; equivalent
    functionality is provided by the `gaf' command.
  * `convert_sym.awk' has been removed from the distribution; equivalent
    functionality is provided by the `convert_sym' command.
  * New scheme procedures and hooks have been added
  * Removal of some scripts and programs
  * Updated translations
  * Various bugfixes
  For more details see: /usr/share/doc/packages/geda-gaf/NEWS
- New subpackages:
  * libgedacairo45
  * libgedacairo-devel
- Add patches:
  * geda-gaf-disable-failing-tests.patch: disable failing tests
  * geda-gaf-enable-guile-2.2.patch: enable guile-2.2 on Factory/TW
- Increase version of libgeda to 45
- Install more languages files
- Add and remove files for packages where necessary
- Remove unnecessary requires on libgeda, which are found by rpm
  itself
- Update source link
- Improve phrasing in summaries
- Fixes boo#1117307: geda-gaf now requires at least guile-2.0 and
  seems to work also with guile-2.2
- Remove deprecated defattr statements
- Use license and doc macro
* Sun May  6 2018 stefan.bruens@rwth-aachen.de
- Move scheme code common to gattrib, gnetlist, gschem and utils
  from gschem subpackage to new geda-base subpackage.
- Remove conditionals for deprecated distributions
* Sat Feb 10 2018 jengelh@inai.de
- Limit descriptions to the package, fix some typos here and there.
- Remove redundant %%clean section.
* Sat Feb  3 2018 bugs@vdm-design.de
- Add patch fix-gxyrs-utility.patch to fix the failed unittest
  when building for factory
* Tue Mar  3 2015 dmitry_r@opensuse.org
- Fix desktop menu categories
* Wed Nov 12 2014 dmitry_r@opensuse.org
- Add geda-gaf-rpmlintrc to source list
* Sat Nov  8 2014 Led <ledest@gmail.com>
- fix bashisms in post/postun scripts
* Wed Oct  2 2013 dmitry_r@opensuse.org
- Update to version 1.8.2
  * Fixed a libgeda crash bug involving nets inside symbols.
  * Fixed a gnetlist data corruption bug when using refdes
    containing the string "POWER".
  * Updates to build system to allow compilation from git on systems
    with Automake >= 1.13.0.
* Mon Jul 29 2013 dmitry_r@opensuse.org
- Fix build for Factory
* Fri Jan  4 2013 dmitry_r@opensuse.org
- Change documentation license to GFDL-1.2
- Add geda-gaf package for consolidation of installation
* Thu Dec 27 2012 dmitry_r@opensuse.org
- Delete "guile" from requires
- Delete compitation time from binary
  * grenum-no-build-time.patch
- Enable post build tests
- Split libgeda data to separate package
* Mon Dec 24 2012 dmitry_r@opensuse.org
- Update to version 1.8.1
  * 'gschem' and 'gnetlist' have updated and rewritten user guides.
  * All tools now give more informative error messages if they are
    unable to load schematic or symbol files due to syntax errors.
  * All tools now correctly handle schematic and symbol files with
    '\r',  '\n', or '\r\n' line endings, or a mixture.
  * Unconnected pin ends and net ends are now all drawn with the
    same box marker in `gschem' and printed output.
  * Net segments with at least two connections (including indirect
    connections via `netname=' attributes) are now drawn with
    arrowheads rather than box markers on dangling ends in 'gschem'
    and printed output.
- Set correct path to documentation
  * gschem-doc-path.patch
* Fri Aug 31 2012 scorot@free.fr
- fix build for 12.2 with patch0
* Tue Dec 27 2011 werner.ho@gmx.de
- updated to unstable version 1.7.1
- fixes BUG #738587
* Sun Nov 20 2011 werner.ho@gmx.de
- linker flag fix (-lm) for openSuSE 12.1
* Sun Jan 16 2011 werner.ho@gmx.de
- new version 1.6.2
* Fri Feb 26 2010 werner.ho@gmx.de
- new version 1.6.1
* Sat Oct 10 2009 werner.ho@gmx.de
- first build of unified geda-gaf package version 1.6.0
